# Code Reference - Custom Information - Units

The definitions for the "units" information classes, i.e. columnwise unit definitions.

## df_file_interchange.ci.unit.base

::: df_file_interchange.ci.unit.base.FIBaseUnit

::: df_file_interchange.ci.unit.base.FIGenericUnit

## df_file_interchange.ci.unit.currency

::: df_file_interchange.ci.unit.currency.FICurrencyUnit

## df_file_interchange.ci.unit.population

::: df_file_interchange.ci.unit.population.FIPopulationUnit

